@@ -6,11 +6,12 @@ async def main():
     config = read_config_file("config.yaml")
     bot_username = config["bot"]["username"]
     bot_password = config["bot"]["password"]
+    bot_display_name = config["bot"]["display_name"]
     device_id = config["device"]["id"]
     device_name = config["device"]["name"]
     
     duckbot = await DuckBot.create(config)
 
-    await duckbot.run(bot_username, bot_password, device_id, device_name)
+    await duckbot.run(bot_username, bot_password, device_id, device_name, bot_display_name)
 
 asyncio.run(main())
